@@ -75,6 +75,14 @@ sub exploreTopologyJob {
   while (my $data = $queue->dequeue_nb()) {
     push @{$result->{$_}}, @{$data->{$_}} for qw(success fail);
   }
+
+  for my $type (qw(success fail)) {
+    if (my $count = @{$result->{$type}}) {
+      unshift @{$result->{$type}}, sprintf "[exploreTopologyJob] 邻居发现任务执行完毕，执行%s共计：%d",
+        $type eq 'success' ? '成功' : '异常', $count;
+    }
+  }
+
   $self->dump("[exploreTopologyJob] 邻居发现任务执行完毕，正在将运行结果写入日志文件中");
 
   for my $type (qw(success fail)) {
@@ -174,6 +182,13 @@ sub dump {
     my $workdir = "$basedir/dump/$self->{month}/$self->{date}";
     make_path($workdir) unless -d $workdir;
 
+    my $enc = Encode::Guess->guess($text);
+    ref($enc) or croak "无法猜测编码: $enc";
+    eval { $text = $enc->decode($text); };
+    if (!!$@) {
+      warn("字符串($text)解码失败：$@") if $self->debug == 0;
+    }
+
     my $filename = "$workdir/netdisco_dump.txt";
     open(my $fh, '>>:encoding(UTF-8)', $filename) or croak "无法打开文件 $filename 进行写入: $!";
     print $fh "$text\n"                           or croak "写入文件 $filename 失败: $!";
